@@ -28,8 +28,6 @@ DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * $Id: debuglog.h 7004 2014-10-02 09:26:36Z rousseau $
  */
 
 /**
@@ -127,7 +125,7 @@ PCSC_API void log_xxd(const int priority, const char *msg,
 
 void DebugLogSuppress(const int);
 void DebugLogSetLogType(const int);
-int DebugLogSetCategory(const int);
+void DebugLogSetCategory(const int);
 void DebugLogCategory(const int, const unsigned char *, const int);
 PCSC_API void DebugLogSetLevel(const int level);
 
